<?php

$EM_CONF[$_EXTKEY] = [
    'title' => 'SG Sitepackage',
    'description' => 'SG Site Provider Package for TYPO3 Websites',
    'category' => 'templates',
    'constraints' => [
        'depends' => [
            'typo3' => '10.4.0-10.4.99',
            'fluid_styled_content' => '10.4.0-10.4.99',
            'rte_ckeditor' => '10.4.0-10.4.99'
        ],
        'conflicts' => [
        ],
    ],
    'autoload' => [
        'psr-4' => [
            'SG\\SgSitepackage\\' => 'Classes'
        ],
    ],
    'state' => 'beta',
    'version' => '10.1.0',
    'author' => 'Daniel Hoffmann, Marc Saleiko',
    'author_email' => 'hoffmann@smply.gd, saleiko@smply.gd',
    'author_company' => 'Smply.gd GmbH',
    'uploadfolder' => 0,
    'createDirs' => 'fileadmin/user_upload/forms,fileadmin/avatars',
    'clearCacheOnLoad' => 1,
];
